package
Version:
v0.7.0
Opens a new window with list of versions in this module.
Published: Jun 11, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package notify shows best-effort desktop notifications.
func Notify(title, body string)
Notify posts a desktop notification. No-op when the body is empty or
DSCAN_NO_NOTIFY is set (tests/headless).
Source Files
¶
Click to show internal directories.
Click to hide internal directories.